Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the API. +groupName=gravity.mobike.io
Index ¶
Constants ¶
const ( GroupName = "gravity.mobike.io" PipelineResourceKind = "Pipeline" )
const (
ConfigFileKey = "config.json"
)
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var (
SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1alpha1"}
)
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Pipeline ¶
type Pipeline struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PipelineSpec `json:"spec"`
Status PipelineStatus `json:"status"`
}
Pipeline is a specification for a Pipeline resource
func (*Pipeline) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Pipeline.
func (*Pipeline) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Pipeline) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PipelineCondition ¶
type PipelineCondition struct {
// Type of cluster condition.
Type PipelineConditionType `json:"type"`
// Status of the condition, one of True, False, Unknown.
Status corev1.ConditionStatus `json:"status"`
// LastUpdateTime is the last time this condition was updated.
LastUpdateTime metav1.Time `json:"lastUpdateTime,omitempty"`
// LastTransitionTime is the last time the condition transitioned from one status to another.
LastTransitionTime metav1.Time `json:"lastTransitionTime,omitempty"`
// Reason for the condition's last transition.
Reason string `json:"reason,omitempty"`
// Message which is human readable indicating details about the transition.
Message string `json:"message,omitempty"`
}
func (*PipelineCondition) DeepCopy ¶
func (in *PipelineCondition) DeepCopy() *PipelineCondition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineCondition.
func (*PipelineCondition) DeepCopyInto ¶
func (in *PipelineCondition) DeepCopyInto(out *PipelineCondition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineConditionType ¶
type PipelineConditionType string
const ( PipelineConditionRunning PipelineConditionType = "Running" PipelineConditionStream PipelineConditionType = "Stream" )
type PipelineList ¶
type PipelineList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Pipeline `json:"items"`
}
PipelineList is a list of Pipeline resources
func (*PipelineList) DeepCopy ¶
func (in *PipelineList) DeepCopy() *PipelineList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineList.
func (*PipelineList) DeepCopyInto ¶
func (in *PipelineList) DeepCopyInto(out *PipelineList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PipelineList) DeepCopyObject ¶
func (in *PipelineList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PipelineSpec ¶
type PipelineSpec struct {
Task `json:",inline"`
Paused bool `json:"paused"`
LastUpdate metav1.Time `json:"lastUpdate"`
}
PipelineSpec is the spec for a Pipeline resource
func (*PipelineSpec) DeepCopy ¶
func (in *PipelineSpec) DeepCopy() *PipelineSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineSpec.
func (*PipelineSpec) DeepCopyInto ¶
func (in *PipelineSpec) DeepCopyInto(out *PipelineSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineStatus ¶
type PipelineStatus struct {
ObservedGeneration int64 `json:"observedGeneration"`
Task `json:",inline"`
Position string `json:"position"`
PodName string `json:"podName"`
Conditions []PipelineCondition `json:"conditions,omitempty"`
}
PipelineStatus is the status for a Pipeline resource
func (PipelineStatus) Available ¶
func (t PipelineStatus) Available() bool
func (PipelineStatus) Condition ¶
func (t PipelineStatus) Condition(condType PipelineConditionType) *PipelineCondition
func (*PipelineStatus) DeepCopy ¶
func (in *PipelineStatus) DeepCopy() *PipelineStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineStatus.
func (*PipelineStatus) DeepCopyInto ¶
func (in *PipelineStatus) DeepCopyInto(out *PipelineStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Task ¶
type Task struct {
ConfigHash string `json:"configHash"`
Image string `json:"image"`
Command []string `json:"command"`
}
func (*Task) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Task.
func (*Task) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.