Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterExpansion ¶
type ClusterExpansion interface{}
type ClusterInterface ¶
type ClusterInterface interface {
Create(*v1alpha1.Cluster) (*v1alpha1.Cluster, error)
Update(*v1alpha1.Cluster) (*v1alpha1.Cluster, error)
UpdateStatus(*v1alpha1.Cluster) (*v1alpha1.Cluster, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Cluster, error)
List(opts v1.ListOptions) (*v1alpha1.ClusterList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Cluster, err error)
ClusterExpansion
}
ClusterInterface has methods to work with Cluster resources.
type ClustersGetter ¶
type ClustersGetter interface {
Clusters(namespace string) ClusterInterface
}
ClustersGetter has a method to return a ClusterInterface. A group's client should implement this interface.
type GravityV1alpha1Client ¶
type GravityV1alpha1Client struct {
// contains filtered or unexported fields
}
GravityV1alpha1Client is used to interact with features provided by the gravity.mobike.io group.
func New ¶
func New(c rest.Interface) *GravityV1alpha1Client
New creates a new GravityV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*GravityV1alpha1Client, error)
NewForConfig creates a new GravityV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *GravityV1alpha1Client
NewForConfigOrDie creates a new GravityV1alpha1Client for the given config and panics if there is an error in the config.
func (*GravityV1alpha1Client) Clusters ¶
func (c *GravityV1alpha1Client) Clusters(namespace string) ClusterInterface
func (*GravityV1alpha1Client) RESTClient ¶
func (c *GravityV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type GravityV1alpha1Interface ¶
type GravityV1alpha1Interface interface {
RESTClient() rest.Interface
ClustersGetter
}