Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GravityV1alpha1Client ¶
type GravityV1alpha1Client struct {
// contains filtered or unexported fields
}
GravityV1alpha1Client is used to interact with features provided by the gravity.mobike.io group.
func New ¶
func New(c rest.Interface) *GravityV1alpha1Client
New creates a new GravityV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*GravityV1alpha1Client, error)
NewForConfig creates a new GravityV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *GravityV1alpha1Client
NewForConfigOrDie creates a new GravityV1alpha1Client for the given config and panics if there is an error in the config.
func (*GravityV1alpha1Client) Pipelines ¶
func (c *GravityV1alpha1Client) Pipelines(namespace string) PipelineInterface
func (*GravityV1alpha1Client) RESTClient ¶
func (c *GravityV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type GravityV1alpha1Interface ¶
type GravityV1alpha1Interface interface {
RESTClient() rest.Interface
PipelinesGetter
}
type PipelineExpansion ¶
type PipelineExpansion interface{}
type PipelineInterface ¶
type PipelineInterface interface {
Create(*v1alpha1.Pipeline) (*v1alpha1.Pipeline, error)
Update(*v1alpha1.Pipeline) (*v1alpha1.Pipeline, error)
UpdateStatus(*v1alpha1.Pipeline) (*v1alpha1.Pipeline, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Pipeline, error)
List(opts v1.ListOptions) (*v1alpha1.PipelineList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Pipeline, err error)
PipelineExpansion
}
PipelineInterface has methods to work with Pipeline resources.
type PipelinesGetter ¶
type PipelinesGetter interface {
Pipelines(namespace string) PipelineInterface
}
PipelinesGetter has a method to return a PipelineInterface. A group's client should implement this interface.